package org.greenstone.gsdl3.gs3build.metadata;

/**
 *  A METS document representation - the METS objects are represented
 *  by hand-coded classes rather than JAXB products due to the fact
 *  that we want wrappers to provide higher-level abstractions than
 *  the basic METS XML mark-up.
 */

import java.util.Map;
import java.util.HashMap;

import java.io.File;
import java.net.URL;

public class METSDocument
{
	// TODO: add use of 'ID'
	String objectID;
	String label;
	String type;
	// TODO: add use of 'PROFILE';

	METSHeader      header;
	METSDescriptiveSet descriptiveSet;
	METSAdmin       admin;
	METSFileSet     fileSet;

	public METSDocument(String identifier)
	{
		this.objectID = identifier; // In Greenstone land, this should be a unique identifier within
		                            // the current collection
		this.type = "document"; // Types in METS are just strings - we currently use
		                        // 'Document' as a standard representation.
                            // Individual options should be defined in a published
														// METS Profile - in Greenstone we currently 'cheat'
														// and bodge the system
		this.header      = new METSHeader();
		this.descriptiveSet = new METSDescriptiveSet();
		this.fileSet     = new METSFileSet();
	}

	/**
	 *  Set the document identifier for this document
	 *
	 *  @param <code>String</code> the identifier
	 */
	public void setDocId(String id)
	{	this.objectID = id;
	}

	public String getDocId()
	{	return this.objectID;
	}

	public METSHeader getHeader()
	{	return this.header;
	}	

	public void setHeader(METSHeader header)
	{	this.header = header;
	}

	public void addFile(METSFile file)
	{	this.fileSet.addFile(file);
	}

	public void addFile(URL url)
	{	this.fileSet.addFile(url);
	}

	public void addFile(METSFile file, String toGroup)
	{	this.fileSet.addFile(file, toGroup);
	}
}
